# Nepali Toolkit

- All Required Nepali Utilities for your python application.

Python package for Nepali phone, postal code, PAN, citizenship, and date validations.

## Installation

```bash
pip install nepali-datetime
```
